@@ -11,7 +11,7 @@ use File::Share ':all';
 use Geo::Details;
 use Net::CIDR::Lite;
 
-our $VERSION = '2.1.2';
+our $VERSION = '2.1.3';
 use constant DEFAULT_CACHE_MAX_SIZE        => 4096;
 use constant DEFAULT_CACHE_TTL             => 86_400;
 use constant DEFAULT_COUNTRY_FILE          => 'countries.json';
@@ -19,7 +19,7 @@ use constant DEFAULT_EU_COUNTRY_FILE       => 'eu.json';
 use constant DEFAULT_COUNTRY_FLAG_FILE     => 'flags.json';
 use constant DEFAULT_COUNTRY_CURRENCY_FILE => 'currency.json';
 use constant DEFAULT_CONTINENT_FILE        => 'continent.json';
-use constant DEFAULT_TIMEOUT               => 2;
+use constant DEFAULT_TIMEOUT               => 3;
 use constant HTTP_TOO_MANY_REQUEST         => 429;
 
 my %valid_fields = (
@@ -214,7 +214,7 @@ sub _lookup_info {
         $source_info->{country_currency} =
           $self->{countries_currencies}->{$country};
         $source_info->{continent} = $self->{continents}->{$country};
-        if ( $country ~~ $self->{eu_countries} ) {
+        if ( grep { $_ eq $country } @{ $self->{eu_countries} } ) {
             $source_info->{is_eu} = "True";
         }
         else {
@@ -367,10 +367,8 @@ Geo::IPinfo -  The official Perl library for IPinfo.
 
 =head1 VERSION
 
-Version 2.1.2
-  - Added support for API response of type text/content.
-  - Added following named methods: abuse, org, domains, privacy and timezone.
-  - Fixed tests.
+Version 2.1.3
+  - Enabled JSON encoding
 
 =cut
 
